@@ -1,9 +1,10 @@
 from nonebot import on_command, get_driver
-from nonebot.adapters.onebot.v11 import Bot, Message, GroupMessageEvent, GROUP, GROUP_ADMIN, GROUP_OWNER
+from nonebot.adapters.onebot.v11 import Bot, Message, MessageSegment, GroupMessageEvent, GROUP, GROUP_ADMIN, GROUP_OWNER
 from nonebot.params import CommandArg
 from nonebot.plugin import PluginMetadata
 from nonebot.permission import SUPERUSER
 from nonebot_plugin_apscheduler import scheduler
+from nonebot_plugin_txt2img import Txt2Img
 from httpx import AsyncClient
 from .config import Config
 
@@ -11,13 +12,16 @@ __plugin_meta__ = PluginMetadata(
     'Apex API Query',
     'Apex Legends API 查询插件',
     '''
-    /bridge [玩家名称] -根据玩家名称玩家信息\n
-    /uid [玩家UID] -根据玩家UID查询玩家信息\n
-    /maprotation -查询地图轮换\n
-    /predator -查询顶尖猎杀者\n
-    /crafting -查询制造轮换\n
-    /submap -订阅地图轮换[每整点查询]\n
-    /subcraft -订阅制造轮换[每日2时查询]
+    `/bridge [玩家名称]` 、`/玩家 [玩家名称]` - 根据玩家名称查询玩家信息 (暂仅支持查询 PC 平台玩家信息), 
+    `/uid [玩家UID]`、`/UID [玩家UID]` - 根据玩家 UID 查询玩家信息 (暂仅支持查询 PC 平台玩家信息), 
+    `/maprotation` 、 `/地图` - 查询当前地图轮换, 
+    `/predator` 、 `/猎杀` - 查询顶尖猎杀者信息, 
+    `/crafting` 、 `/制造` - 查询当前制造轮换, 
+    `/servers`、`/服务` - 查看当前服务器状态, 
+    `/submap`、`/订阅地图` - 订阅地图轮换(每整点查询)(仅群聊可用), 
+    `/unsubmap`、`/取消订阅地图` - 取消订阅地图轮换(仅群聊可用), 
+    `/subcraft`、`/订阅制造` - 订阅制造轮换(每日2时查询)(仅群聊可用), 
+    `/unsubcraft`、`/取消订阅制造` - 取消订阅制造轮换(仅群聊可用).
     '''
 )
 
@@ -25,12 +29,14 @@ plugin_config = Config.parse_obj(get_driver().config)
 
 api_key = plugin_config.apex_api_key
 api_url = plugin_config.apex_api_url
+api_t2i = plugin_config.apex_api_t2i
 
 player_statistics = on_command('bridge', aliases= {'玩家'})
 uid_statistics = on_command('uid', aliases={'UID'})
 map_protation = on_command('maprotation', aliases={'地图'})
 predator = on_command('predator', aliases={'猎杀'})
 crafting_rotation = on_command('crafting', aliases={'制造'})
+servers = on_command('servers', aliases={'服务'})
 sub_map = on_command('submap', aliases={'订阅地图'}, permission=GROUP and SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
 unsub_map = on_command('unsubmap', aliases={'取消订阅地图'}, permission=GROUP and SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
 sub_craft = on_command('subcraft', aliases={'订阅制造'}, permission=GROUP and SUPERUSER | GROUP_ADMIN | GROUP_OWNER)
@@ -43,7 +49,11 @@ async def _(player_name: Message = CommandArg()):
     payload = {'auth': api_key, 'player': str(player_name), 'platform': 'PC'}
     await player_statistics.send('正在查询: 玩家 {}'.format(player_name))
     response = await api_query(service, payload)
-    await player_statistics.send(response)
+    if api_t2i:
+        msg = t2i(service, response)
+    else:
+        msg = response
+    await player_statistics.send(msg)
 
 # 玩家 UID 查询
 @uid_statistics.handle()
@@ -52,7 +62,11 @@ async def _(player_name: Message = CommandArg()):
     payload = {'auth': api_key, 'uid': str(player_name), 'platform': 'PC'}
     await uid_statistics.send('正在查询: UID {}'.format(player_name))
     response = await api_query(service, payload)
-    await uid_statistics.send(response)
+    if api_t2i:
+        msg = t2i(service, response)
+    else:
+        msg = response
+    await uid_statistics.send(msg)
 
 # 地图轮换查询
 @map_protation.handle()
@@ -61,7 +75,11 @@ async def _():
     payload = {'auth': api_key, 'version': '2'}
     await map_protation.send('正在查询: 地图轮换')
     response = await api_query(service, payload)
-    await map_protation.send(response)
+    if api_t2i:
+        msg = t2i(service, response)
+    else:
+        msg = response
+    await map_protation.send(msg)
 
 # 顶尖猎杀者查询
 @predator.handle()
@@ -70,7 +88,11 @@ async def _():
     payload = {'auth': api_key}
     await predator.send('正在查询: 顶尖猎杀者')
     response = await api_query(service, payload)
-    await predator.send(response)
+    if api_t2i:
+        msg = t2i(service, response)
+    else:
+        msg = response
+    await predator.send(msg)
 
 # 制造轮换查询
 @crafting_rotation.handle()
@@ -79,24 +101,50 @@ async def _():
     payload = {'auth': api_key}
     await crafting_rotation.send('正在查询: 制造轮换')
     response = await api_query(service, payload)
-    await crafting_rotation.send(response)
+    if api_t2i:
+        msg = t2i(service, response)
+    else:
+        msg = response
+    await crafting_rotation.send(msg)
+
+# 服务器状态查询
+@servers.handle()
+async def _():
+    service = 'servers'
+    payload = {'auth': api_key}
+    await servers.send('正在查询: 服务器状态')
+    response = await api_query(service, payload)
+    if api_t2i:
+        msg = t2i(service, response)
+    else:
+        msg = response
+    await servers.send(msg)
 
 # 订阅地图轮换
 @sub_map.handle()
 async def _(bot: Bot, event: GroupMessageEvent):
     try:
-        scheduler.add_job(func=submap, trigger='cron', id=(str(event.group_id) + '_map'), minute=1, kwargs={'bot': bot, 'group_id': event.group_id})
+        scheduler.add_job(func=submap, trigger='cron', id=(str(event.group_id) + '_map'), minute=1, kwargs={'bot': bot, 'group_id': event.group_id, 'api_t2i': api_t2i})
         await sub_map.send('已订阅地图轮换')
     except BaseException as err:
         await sub_map.send('订阅地图轮换失败: {}'.format(err))
 
 # 地图轮换定时任务
-async def submap(bot, group_id):
+async def submap(bot, group_id, api_t2i):
     service = 'maprotation'
     payload = {'auth': api_key, 'version': '2'}
     await bot.send_group_msg(group_id=group_id, message='正在查询: 地图轮换')
     response = await api_query(service, payload)
-    await bot.send_group_msg(group_id=group_id, message=response)
+    if api_t2i:
+        title = '地图轮换'
+        font_size = 32
+        text = response
+        Txt2Img().set_font_size(font_size)
+        pic = Txt2Img().draw(title, text)
+        msg = MessageSegment.image(pic)
+    else:
+        msg = response
+    await bot.send_group_msg(group_id=group_id, message=msg)
 
 # 取消订阅地图轮换
 @unsub_map.handle()
@@ -111,18 +159,27 @@ async def _(event: GroupMessageEvent):
 @sub_craft.handle()
 async def _(bot: Bot, event: GroupMessageEvent):
     try:
-        scheduler.add_job(func=subcraft, trigger='cron', id=(str(event.group_id) + '_craft'), hour=2, minute=1, kwargs={'bot': bot, 'group_id': event.group_id})
+        scheduler.add_job(func=subcraft, trigger='cron', id=(str(event.group_id) + '_craft'), hour=2, minute=1, kwargs={'bot': bot, 'group_id': event.group_id, 'api_t2i': api_t2i})
         await sub_craft.send('已订阅制造轮换')
     except BaseException as err:
         await sub_craft.send('订阅制造轮换失败: {}'.format(err))
 
 # 制造轮换定时任务
-async def subcraft(bot, group_id):
+async def subcraft(bot, group_id, api_t2i):
     service = 'crafting'
     payload = {'auth': api_key}
     await bot.send_group_msg(group_id=group_id, message='正在查询: 制造轮换')
     response = await api_query(service, payload)
-    await bot.send_group_msg(group_id=group_id, message=response)
+    if api_t2i:
+        title = '制造轮换'
+        font_size = 32
+        text = response
+        Txt2Img().set_font_size(font_size)
+        pic = Txt2Img().draw(title, text)
+        msg = MessageSegment.image(pic)
+    else:
+        msg = response
+    await bot.send_group_msg(group_id=group_id, message=msg)
 
 # 取消订阅制造轮换
 @unsub_craft.handle()
@@ -147,7 +204,27 @@ async def api_query(service, payload):
         data = '查询失败: 网络错误: {}'.format(err)
         return data
 
-# 发送内容文本
+# txt2img
+def t2i(service, response):
+    if service == 'bridge':
+        title = '玩家查询'
+    elif service == 'maprotation':
+        title = '地图轮换'
+    elif service == 'predator':
+        title = '顶尖猎杀者'
+    elif service == 'crafting':
+        title = '制造轮换'
+    elif service == 'servers':
+        title = '服务器状态'
+    font_size = 32
+    text = response
+    Txt2Img().set_font_size(font_size)
+    pic = Txt2Img().draw(title, text)
+    msg = MessageSegment.image(pic)
+    return msg
+
+
+# 处理获取信息
 def process(service, response):
 
     # 玩家数据
@@ -174,7 +251,8 @@ def process(service, response):
             '可加入: {}\n'
             '群满员: {}\n'
             '已选传奇: {}\n'
-            '当前状态: {}'
+            '当前状态: {}\n'
+            '状态: {}'
             .format(
                 globals.get('name'),
                 globals.get('uid'),
@@ -196,7 +274,8 @@ def process(service, response):
                 convert(realtime.get('canJoin')),
                 convert(realtime.get('partyFull')),
                 convert(realtime.get('selectedLegend')),
-                convert(realtime.get('currentState'))
+                convert(realtime.get('currentState')),
+                realtime.get('currentStateAsText')
             )
         )
         return data
@@ -359,7 +438,95 @@ def process(service, response):
             )
         )
         return data
-    return data
+    
+    # 服务器数据
+    elif service == 'servers':
+        data = (
+            'Origin 登录:\n'
+            '欧盟西部: {}\n'
+            '欧盟东部: {}\n'
+            '美国西部: {}\n'
+            '美国中部: {}\n'
+            '美国东部: {}\n'
+            '南美洲: {}\n'
+            '亚洲: {}\n\n'
+            'EA 融合:\n'
+            '欧盟西部: {}\n'
+            '欧盟东部: {}\n'
+            '美国西部: {}\n'
+            '美国中部: {}\n'
+            '美国东部: {}\n'
+            '南美洲: {}\n'
+            '亚洲: {}\n\n'
+            'EA 账户:\n'
+            '欧盟西部: {}\n'
+            '欧盟东部: {}\n'
+            '美国西部: {}\n'
+            '美国中部: {}\n'
+            '美国东部: {}\n'
+            '南美洲: {}\n'
+            '亚洲: {}\n\n'
+            'Apex 跨平台验证:\n'
+            '欧盟西部: {}\n'
+            '欧盟东部: {}\n'
+            '美国西部: {}\n'
+            '美国中部: {}\n'
+            '美国东部: {}\n'
+            '南美洲: {}\n'
+            '亚洲: {}\n\n'
+            '自我核心测试:\n'
+            '网站状态: {}\n'
+            '统计 API: {}\n'
+            '溢出 #1: {}\n'
+            '溢出 #2: {}\n'
+            'Origin API: {}\n'
+            'Playstation API: {}\n'
+            'Xbox API: {}\n\n'
+            '其他平台:\n'
+            'Playstation Network: {}\n'
+            'Xbox Live: {}\n\n'
+            'Data from apexlegendsstatus.com'
+            .format(
+                convert(response.json().get('Origin_login').get('EU-West').get('Status')),
+                convert(response.json().get('Origin_login').get('EU-East').get('Status')),
+                convert(response.json().get('Origin_login').get('US-West').get('Status')),
+                convert(response.json().get('Origin_login').get('US-Central').get('Status')),
+                convert(response.json().get('Origin_login').get('US-East').get('Status')),
+                convert(response.json().get('Origin_login').get('SouthAmerica').get('Status')),
+                convert(response.json().get('Origin_login').get('Asia').get('Status')),
+                convert(response.json().get('EA_novafusion').get('EU-West').get('Status')),
+                convert(response.json().get('EA_novafusion').get('EU-East').get('Status')),
+                convert(response.json().get('EA_novafusion').get('US-West').get('Status')),
+                convert(response.json().get('EA_novafusion').get('US-Central').get('Status')),
+                convert(response.json().get('EA_novafusion').get('US-East').get('Status')),
+                convert(response.json().get('EA_novafusion').get('SouthAmerica').get('Status')),
+                convert(response.json().get('EA_novafusion').get('Asia').get('Status')),
+                convert(response.json().get('EA_accounts').get('EU-West').get('Status')),
+                convert(response.json().get('EA_accounts').get('EU-East').get('Status')),
+                convert(response.json().get('EA_accounts').get('US-West').get('Status')),
+                convert(response.json().get('EA_accounts').get('US-Central').get('Status')),
+                convert(response.json().get('EA_accounts').get('US-East').get('Status')),
+                convert(response.json().get('EA_accounts').get('SouthAmerica').get('Status')),
+                convert(response.json().get('EA_accounts').get('Asia').get('Status')),
+                convert(response.json().get('ApexOauth_Crossplay').get('EU-West').get('Status')),
+                convert(response.json().get('ApexOauth_Crossplay').get('EU-East').get('Status')),
+                convert(response.json().get('ApexOauth_Crossplay').get('US-West').get('Status')),
+                convert(response.json().get('ApexOauth_Crossplay').get('US-Central').get('Status')),
+                convert(response.json().get('ApexOauth_Crossplay').get('US-East').get('Status')),
+                convert(response.json().get('ApexOauth_Crossplay').get('SouthAmerica').get('Status')),
+                convert(response.json().get('ApexOauth_Crossplay').get('Asia').get('Status')),
+                convert(response.json().get('selfCoreTest').get('Status-website').get('Status')),
+                convert(response.json().get('selfCoreTest').get('Stats-API').get('Status')),
+                convert(response.json().get('selfCoreTest').get('Overflow-#1').get('Status')),
+                convert(response.json().get('selfCoreTest').get('Overflow-#2').get('Status')),
+                convert(response.json().get('selfCoreTest').get('Origin-API').get('Status')),
+                convert(response.json().get('selfCoreTest').get('Playstation-API').get('Status')),
+                convert(response.json().get('selfCoreTest').get('Xbox-API').get('Status')),
+                convert(response.json().get('otherPlatforms').get('Playstation-Network').get('Status')),
+                convert(response.json().get('otherPlatforms').get('Xbox-Live').get('Status'))
+            )
+        )
+        return data
 
 # 请求内容转换
 def convert(name):
@@ -375,6 +542,8 @@ def convert(name):
         'Overflow': '熔岩流',
         'Phase runner': '相位穿梭器',
         'Party crasher': '派对破坏者',
+        'Drop Off': '原料场',
+        'Unknown': '未知',
         # Barrels
         'barrel_stabilizer': '枪管稳定器',
         'laser_sight': '激光瞄准镜',
@@ -483,5 +652,25 @@ def convert(name):
         'false': '否',
         'COMPETITIVE_DODGE_COOLDOWN': '竞技逃跑冷却',
         'None': '无',
+        'EU-West': '欧盟西部',
+        'EU-East': '欧盟东部',
+        'US-West': '美国西部',
+        'US-Central': '美国中部',
+        'US-East': '美国东部',
+        'SouthAmerica': '南美洲',
+        'Asia': '亚洲',
+        'Status-website': '网站状态',
+        'Stats-API': '统计 API',
+        'Overflow-#1': '溢出 #1',
+        'Overflow-#2': '溢出 #2',
+        'Origin-API': 'Origin API',
+        'Playstation-API': 'Playstation API',
+        'Xbox-API': 'Xbox API',
+        'Playstation-Network': 'Playstation Network',
+        'Xbox-Live': 'Xbox Live',
+        'UP': '在线',
+        'DOWN': '离线',
+        'SLOW': '缓慢',
+        'OVERLOADED': '过载',
     }
     return names.get(name, name)
